#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 control-monad-free
version:              0.6.2
visibility:           public
id:                   control-monad-free-0.6.2-6nHvGxzfOoN2NFMaDlBoMl
key:                  control-monad-free-0.6.2-6nHvGxzfOoN2NFMaDlBoMl
license:              LicenseRef-PublicDomain
maintainer:           pepeiborra@gmail.com
author:               Luke Palmer, Pepe Iborra
stability:            stable
homepage:             http://github.com/pepeiborra/control-monad-free
synopsis:             Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:

    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/

category:             Control, Monads
abi:                  f400d24dc4943016fc96a1b8d4824519
exposed:              True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip

import-dirs:          /usr/lib/ghc-8.10.5/site-local/control-monad-free-0.6.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/control-monad-free-0.6.2
hs-libraries:         HScontrol-monad-free-0.6.2-6nHvGxzfOoN2NFMaDlBoMl
depends:              base-4.14.2.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock

haddock-html:         /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

